@@ -1,8 +1,10 @@
-__version__ = "0.11.1"
+__version__ = "0.13.0"
 
 import sys
 
 from gym.envs.registration import register
+from .main import run
+from .sequences_diff import compare
 
 
 register(
